Module operations

Module operations 

Operations

The operations module contains all the operations that can be performed on a value. Boolean operations can be performed on any value, by converting it to a boolean first. Bitwise operations can be performed on any value, which can be converted to an integer. Arithmetic operations can be performed on numeric values, and on strings (for some ops) Indexing operations can be performed on arrays, objects, strings, and ranges Mutable indexing operations can be performed on arrays and objects

Enums

ArithmeticOperation
Available arithmetic operations
BitwiseOperation
Available bitwise operations
BooleanOperation
Available boolean operations
MatchingOperation
Matching operations These operations are used to compare two values and return a boolean result

Traits

ArithmeticOperationExt
Trait for arithmetic operations
BitwiseOperationExt
Trait for bitwise operations
BooleanOperationExt
Trait for boolean operations
IndexingMutationExt
A trait for indexing operations that can mutate the value
IndexingOperationExt
Indexing operation trait
MatchingOperationExt
Trait for matching operations