Enum polyvalue::operations::MatchingOperation
source · pub enum MatchingOperation {
Contains,
Matches,
Is,
StartsWith,
EndsWith,
}Expand description
Matching operations These operations are used to compare two values and return a boolean result
Variants
Contains
Matches array or string contents
Matches
Matches a string, array or regular expression
Is
Type-specific matching operations
StartsWith
This is a special case of Matches that matches the start of the target
EndsWith
This is a special case of Matches that matches the end of the target