Array

Struct Array 

pub struct Array(/* private fields */);
Subtype of Value that represents an array

Implementations

Source

impl Array

pub const MAX_CONVERTIBLE_RANGE: usize = 65_536usize

Largest range that can be converted to an array

pub fn pop(&mut self) -> Option<Value>

Pop a value from the array

pub fn push(&mut self, value: Value)

Push a value onto the array

pub fn insert(&mut self, index: usize, value: Value)

Insert a value into the array

pub fn remove(&mut self, index: usize) -> Option<Value>

Remove a value from the array

pub fn get(&self, index: usize) -> Option<&Value>

Get a value from the array, if it exists

pub fn get_mut(&mut self, index: usize) -> Option<&mut Value>

Get a mutable value from the array, if it exists

pub fn len(&self) -> usize

Get the length of the array

pub fn is_empty(&self) -> bool

Determine if the array contains any values

pub fn prealloc_range_conversion(length: usize) -> Result<Self, Error>

Preallocate space for a large array conversion