Struct polyvalue::types::I32

source ·
pub struct I32(/* private fields */);
A subtype of Value that represents a specific integer variant ranging from 8 to 64 bits, signed or unsigned 32 bit signed integer

Implementations

source

impl I32

source

pub fn unsized_bitwise_not(&self) -> Self

Bitwise NOT that attempts to remove the effect of the size of the integer: !1u8 == 0u8 instead of !1u8 == 254u8

source

pub fn logical_lshift(&self, right: i32) -> Result<Self, Error>

Shift that always ignores the msb

source

pub fn logical_rshift(&self, right: i32) -> Result<Self, Error>

Shift that always ignores the msb

source

pub fn arithmetic_lshift(&self, right: i32) -> Result<Self, Error>

Shift that always preserves the msb

source

pub fn arithmetic_rshift(&self, right: i32) -> Result<Self, Error>

Shift that always preserves the msb

source

pub fn from_str_radix(s: &str) -> Result<Self, Error>

Creates a new integer from a string representation of a base-n number The string must be in the form of 0b<binary>, 0o<octal>, 0x<hex>, or 0<octal>