pub struct I64(/* private fields */);Expand description
A subtype of Value that represents a specific integer variant
ranging from 8 to 64 bits, signed or unsigned
64 bit signed integer
Implementations
sourceimpl I64
impl I64
sourcepub fn unsized_bitwise_not(&self) -> Self
pub fn unsized_bitwise_not(&self) -> Self
Bitwise NOT that attempts to remove the effect of the size of the integer:
!1u8 == 0u8 instead of !1u8 == 254u8
sourcepub fn logical_lshift(&self, right: i32) -> Result<Self, Error>
pub fn logical_lshift(&self, right: i32) -> Result<Self, Error>
Shift that always ignores the msb
sourcepub fn logical_rshift(&self, right: i32) -> Result<Self, Error>
pub fn logical_rshift(&self, right: i32) -> Result<Self, Error>
Shift that always ignores the msb
sourcepub fn arithmetic_lshift(&self, right: i32) -> Result<Self, Error>
pub fn arithmetic_lshift(&self, right: i32) -> Result<Self, Error>
Shift that always preserves the msb
sourcepub fn arithmetic_rshift(&self, right: i32) -> Result<Self, Error>
pub fn arithmetic_rshift(&self, right: i32) -> Result<Self, Error>
Shift that always preserves the msb
sourcepub fn from_str_radix(s: &str) -> Result<Self, Error>
pub fn from_str_radix(s: &str) -> Result<Self, Error>
Creates a new integer from a string representation of a base-n number
The string must be in the form of 0b<binary>, 0o<octal>, 0x<hex>, or 0<octal>