Operations
The operations module contains all the operations that can be performed on a value. Boolean operations can be performed on any value, by converting it to a boolean first. Bitwise operations can be performed on any value, which can be converted to an integer. Arithmetic operations can be performed on numeric values, and on strings (for some ops) Indexing operations can be performed on arrays, objects, strings, and ranges Mutable indexing operations can be performed on arrays and objects
Enums
- Arithmetic
Operation - Available arithmetic operations
- Bitwise
Operation - Available bitwise operations
- Boolean
Operation - Available boolean operations
- Matching
Operation - Matching operations These operations are used to compare two values and return a boolean result
Traits
- Arithmetic
Operation Ext - Trait for arithmetic operations
- Bitwise
Operation Ext - Trait for bitwise operations
- Boolean
Operation Ext - Trait for boolean operations
- Indexing
Mutation Ext - A trait for indexing operations that can mutate the value
- Indexing
Operation Ext - Indexing operation trait
- Matching
Operation Ext - Trait for matching operations