Module polyvalue::operations

source ·
Operations

The operations module contains all the operations that can be performed on a value. Boolean operations can be performed on any value, by converting it to a boolean first. Bitwise operations can be performed on any value, which can be converted to an integer. Arithmetic operations can be performed on numeric values, and on strings (for some ops)

Enums

Traits