Module polyvalue::operations
source · Expand description
Operations
The operations module contains all the operations that can be performed on a value. Boolean operations can be performed on any value, by converting it to a boolean first. Bitwise operations can be performed on any value, which can be converted to an integer. Arithmetic operations can be performed on numeric values, and on strings (for some ops)
Enums
- Available arithmetic operations
- Available bitwise operations
- Available boolean operations
- Matching operations These operations are used to compare two values and return a boolean result
Traits
- Trait for arithmetic operations
- Trait for bitwise operations
- Trait for boolean operations
- Indexing operation trait
- Trait for matching operations